/*
 * Control_AQM1602.c
 *
 *  Created on: 2024/11/22
 *      Author: egaono-electronics
 */

#include "Control_AQM1602.h"

#include "Time_Interval.h"


#include <string.h>



//----------------------------------------------------------
// I2C初期化 : AQM1602
//----------------------------------------------------------
// 引数：
// uint8_t *puint8_JobNum : 処理番号が格納される変数のポインタ

// struct sParam_Handle_I2Cx  *pstructParam_Handle_I2Cx
//              Handle I2C用パラメータの構造体のポインタ


// 戻り値：
//   -1 : 処理中
//    0 : OK終了
//    1 : NG終了
//----------------------------------------------------------
int16_t Initialize_I2C_AQM1602(uint8_t *puint8_JobNum,
            struct sParam_Handle_I2Cx  *pstructParam_Handle_I2Cx)
{
  //----------------------------------------------------
  // 呼び出す関数の引数に使用する処理番号は、
  // 必ず static の変数宣言をしてください。
  //----------------------------------------------------
  static uint8_t STC_uint8_JobNum_Time;  // Time_Interval処理番号

  //------------------------------------------------------
  // Time_Interval用パラメータの構造体の宣言は、
  // 使用する関数内で、必ず static で宣言してください。
  //------------------------------------------------------
  // Time_Interval用パラメータの構造体の宣言
  //------------------------------------------------------
  static struct sParam_Time_Interval STC_structParam_Time_Interval;


  GPIO_InitTypeDef GPIO_InitStruct;


  int16_t int16_Return;


  switch(*puint8_JobNum)
  {
  case 0:
    //----------------------------------------------
    // 初期化済みでない場合、初期化する。
    //----------------------------------------------
    if(pstructParam_Handle_I2Cx->int16_vI2C_Initialize_Done == 1){
      // 初期化済みの場合、なにもしないで終了する。
      int16_Return = 0;  // OK
      break;  // 処理終了
    }


    //----------------------------------------------
    // 初期化済みでない場合、初期化処理を行う。
    //----------------------------------------------

    //----------------------------------------------------------
    // SCL と SDA を Low にする。
    //----------------------------------------------------------

    //------------------------------------------------------
    // I2C GPIO pin configuration
    //------------------------------------------------------

    // Enable GPIO Clocks
    __HAL_RCC_GPIOB_CLK_ENABLE();


    //------------------
    // I2C1_SCL
    //------------------
    HAL_GPIO_WritePin(def_GPIOx_I2C1_SCL,
                      def_GPIO_PIN_I2C1_SCL, GPIO_PIN_RESET);

    GPIO_InitStruct.Pin       = def_GPIO_PIN_I2C1_SCL;
    GPIO_InitStruct.Mode      = GPIO_MODE_OUTPUT_PP;
    GPIO_InitStruct.Pull      = GPIO_NOPULL;
    GPIO_InitStruct.Speed     = GPIO_SPEED_HIGH;

    HAL_GPIO_Init(def_GPIOx_I2C1_SCL, &GPIO_InitStruct);


    //------------------
    // I2C1_SDA
    //------------------
    HAL_GPIO_WritePin(def_GPIOx_I2C1_SDA,
                      def_GPIO_PIN_I2C1_SDA, GPIO_PIN_RESET);

    GPIO_InitStruct.Pin       = def_GPIO_PIN_I2C1_SDA;

    HAL_GPIO_Init(def_GPIOx_I2C1_SDA, &GPIO_InitStruct);
    //------------------------------------------------------

    //----------------------------------------------------------


    STC_uint8_JobNum_Time = 0;  // Time_Interval処理番号初期化
    STC_structParam_Time_Interval.uint32_Interval = (uint32_t)10;
                                // 待ち時間セット : 10mSec


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 1:
    //----------------------------------------------------------
    // 時間待ち : 単位 mSec
    //----------------------------------------------------------
    // 戻り値が -1 以外になるまで、繰り返し呼び出してください。
    //----------------------------------------------------------
    // 引数 :
    // uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

    // struct sParam_Time_Interval *pstructParam_Time_Interval :
    //              Time_Interval用パラメータの構造体のポインタ


    // 戻り値 :
    //   -1 : 処理中 : 時間が経過していない。
    //    0 : OK終了 : 時間が経過した。
    //    1 : NG終了
    //----------------------------------------------------------
    int16_Return = Time_Interval(&STC_uint8_JobNum_Time,
                                 &STC_structParam_Time_Interval);
    if(int16_Return == -1){
      // 処理中 : 時間未経過
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    //----------------------------------------------------------
    // I2Cx 初期化
    //----------------------------------------------------------
    //引数　：
    // I2C_TypeDef *I2Cx :
    //      where x can be 1 or 2 to select the I2C peripheral.
    // I2C_HandleTypeDef *pHandle_I2C : I2C handler declaration

    // uint32_t uint32_AddressingMode :
    //      Specifies if 7-bit or 10-bit addressing mode
    //                                              is selected.
    //                7bit : I2C_ADDRESSINGMODE_7BIT
    //                10bit : I2C_ADDRESSINGMODE_10BIT

    // uint32_t uint32_ClockSpeed : Specifies the clock frequency.
    //      This parameter must be set to a value lower than 400kHz.

    // uint32_t uint32_I2C_Address :
    //            Specifies the first device own address.
    //            This parameter can be a 7-bit or 10-bit address.


    //戻り値　：
    //    0 : OK
    //    1 : NG
    //----------------------------------------------------------
    int16_Return = Initialize_I2Cx(I2C1,
                                   &Handle_I2C1,
                                   pstructParam_Handle_I2Cx->
                                        uint32_AddressingMode,
                                   pstructParam_Handle_I2Cx->
                                        uint32_vI2C_Clock_Speed,
                                   (uint32_t)def_I2C1_OwnAddress);

    //----------------------------------------------------------
    // アクセスするデバイスのためのSlave Addressは
    //    LCDモジュール AQM1602 にアクセスするときに指定する。
    //----------------------------------------------------------


    *puint8_JobNum = 0;  // 処理番号初期化
    // int16_Return : 結果
    break;  // 処理終了

  default:
    *puint8_JobNum = 0;  // 処理番号初期化
    int16_Return = 1;    // NG
    break;  // NG
  }

  return(int16_Return);
}


//----------------------------------------------------------
// AQM1602 の初期設定を行う。
//----------------------------------------------------------
// 引数：
// uint8_t *puint8_JobNum : 処理番号が格納される変数のポインタ

// struct sParam_Handle_I2Cx  *pstructParam_Handle_I2Cx :
//              Handle I2C用パラメータの構造体のポインタ


// 戻り値：
//   -1 : 処理中
//    0 : OK終了
//    1 : NG終了
//----------------------------------------------------------
int16_t Initial_Setting_AQM1602(uint8_t *puint8_JobNum,
            struct sParam_Handle_I2Cx  *pstructParam_Handle_I2Cx)
{
  //----------------------------------------------------
  // 呼び出す関数の引数に使用する処理番号は、
  // 必ず static の変数宣言をしてください。
  //----------------------------------------------------
  static uint8_t STC_uint8_JobNum_Time;  // Time_Interval処理番号

  //--------------------------------------------------------
  // Time_Interval用パラメータの構造体の宣言は、
  // 使用する関数内で、必ず static で宣言してください。
  //--------------------------------------------------------
  // Time_Interval用パラメータの構造体の宣言
  //--------------------------------------------------------
  static struct sParam_Time_Interval STC_structParam_Time_Interval;


  static uint8_t STC_uint8_JobNum_LCD;  // LCD処理番号

  static uint8_t STC_uint8_Number_TX;   // 送信データ数
  static uint8_t STC_uint8_aData_TX[8];  // 送信データを格納する配列


  int16_t int16_Return;


  switch(*puint8_JobNum)
  {
  case 0:
    STC_uint8_JobNum_LCD = 0;  // LCD処理番号初期化


    STC_uint8_JobNum_Time = 0;  // Time_Interval処理番号初期化

    // 電源ON時の待ち時間セット
    STC_structParam_Time_Interval.uint32_Interval = (uint32_t)50;
                                // 待ち時間セット : 50mSec


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 1:
    //----------------------------------
    // 電源ON時の時間待ち
    //----------------------------------
    //----------------------------------------------------------
    // 時間待ち : 単位 mSec
    //----------------------------------------------------------
    // 戻り値が -1 以外になるまで、繰り返し呼び出してください。
    //----------------------------------------------------------
    // 引数:
    // uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

    // struct sParam_Time_Interval *pstructParam_Time_Interval :
    //              Time_Interval用パラメータの構造体のポインタ


    // 戻り値:
    //   -1 : 処理中 : 時間が経過していない。
    //    0 : OK終了 : 時間が経過した。
    //    1 : NG終了
    //----------------------------------------------------------
    int16_Return = Time_Interval(&STC_uint8_JobNum_Time,
                                 &STC_structParam_Time_Interval);
    if(int16_Return == -1){
      // 処理中 : 時間未経過
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    STC_uint8_Number_TX = 5;  // 送信データ数セット

    // 初期設定データセット
    STC_uint8_aData_TX[0] = 0x38;  // FUNCTION SET
                                  // DL = 1 : 8bit bus
                                  // N = 1 : 2-line display mode
                                  // IS = 0 : normal instruction

    STC_uint8_aData_TX[1] = 0x39;  // FUNCTION SET
                                  // DL = 1 : 8bit bus
                                  // N = 1 : 2-line display mode
                                  // IS = 1 : extension instruction

    STC_uint8_aData_TX[2] = 0x14;  // Internal OSC frequency adjustment
    STC_uint8_aData_TX[3] = 0x78;  // Power / ICON control / Contrast set
    STC_uint8_aData_TX[4] = 0x5F;  // Contrast set


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 2:
    //----------------------------------------------------------
    // AQM1602 コマンド書き込み
    //----------------------------------------------------------
    // 引数：
    // uint8_t *puint8_JobNum : 処理番号が格納される変数のポインタ

    // uint8_t uint8_Number_TX : 送信データ数
    // uint8_t *puint8_aData_TX : 送信データを格納するバッファのポインタ

    // uint32_t uint32_Interval : 待ち時間 (mSec)

    // struct sParam_Handle_I2Cx  *pstructParam_Handle_I2Cx
    //              Handle I2C用パラメータの構造体のポインタ


    // 戻り値：
    //   -1 : 処理中
    //    0 : OK終了
    //    1 : NG終了
    //----------------------------------------------------------
    int16_Return = Write_Command_AQM1602(&STC_uint8_JobNum_LCD,
                                         STC_uint8_Number_TX,
                                         STC_uint8_aData_TX,
                                         (uint32_t)2,
                                         pstructParam_Handle_I2Cx);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }

    if(int16_Return != 0){
      // NG終了
      *puint8_JobNum = 0;  // 処理番号初期化
      // int16_Return : 結果
      break;  // 処理終了
    }


    STC_uint8_Number_TX = 1;  // 送信データ数セット

    // 初期設定データセット
    STC_uint8_aData_TX[0] = 0x6A;  // Follower control


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 3:
    //-------------------------------------------------------
    // AQM1602 コマンド書き込み
    //-------------------------------------------------------
    // 引数：
    // uint8_t *puint8_JobNum : 処理番号が格納される変数のポインタ

    // uint8_t uint8_Number_TX : 送信データ数
    // uint8_t *puint8_aData_TX : 送信データを格納するバッファのポインタ

    // uint32_t uint32_Interval : 待ち時間 (mSec)

    // struct sParam_Handle_I2Cx  *pstructParam_Handle_I2Cx
    //              Handle I2C用パラメータの構造体のポインタ


    // 戻り値：
    //   -1 : 処理中
    //    0 : OK終了
    //    1 : NG終了
    //-------------------------------------------------------
    int16_Return = Write_Command_AQM1602(&STC_uint8_JobNum_LCD,
                                         STC_uint8_Number_TX,
                                         STC_uint8_aData_TX,
                                         (uint32_t)200,
                                         pstructParam_Handle_I2Cx);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }

    if(int16_Return != 0){
      // NG終了
      *puint8_JobNum = 0;  // 処理番号初期化
      // int16_Return : 結果
      break;  // 処理終了
    }


    STC_uint8_Number_TX = 3;  // 送信データ数セット

    // 初期設定データセット
    STC_uint8_aData_TX[0] = 0x0C;  // DISPLAY ON
    STC_uint8_aData_TX[1] = 0x01;  // CLEAR DISPLAY
    STC_uint8_aData_TX[2] = 0x06;  // ENTRY MODE SET


    (*puint8_JobNum)++;  // 次の処理番号に移行する。 : case 4:
    int16_Return = -1;   // 処理継続
    break;

  case 4:
    //----------------------------------------------------------
    // AQM1602 コマンド書き込み
    //----------------------------------------------------------
    // 引数：
    // uint8_t *puint8_JobNum : 処理番号が格納される変数のポインタ

    // uint8_t uint8_Number_TX : 送信データ数
    // uint8_t *puint8_aData_TX : 送信データを格納するバッファのポインタ

    // uint32_t uint32_Interval : 待ち時間 (mSec)

    // struct sParam_Handle_I2Cx  *pstructParam_Handle_I2Cx
    //              Handle I2C用パラメータの構造体のポインタ


    // 戻り値：
    //   -1 : 処理中
    //    0 : OK終了
    //    1 : NG終了
    //----------------------------------------------------------
    int16_Return = Write_Command_AQM1602(&STC_uint8_JobNum_LCD,
                                         STC_uint8_Number_TX,
                                         STC_uint8_aData_TX,
                                         (uint32_t)3,
                                         pstructParam_Handle_I2Cx);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    *puint8_JobNum = 0;  // 処理番号初期化
    // int16_Return : 結果
    break;  // 処理終了

  default:
    *puint8_JobNum = 0;  // 処理番号初期化
    int16_Return = 1;    // NG
    break;
  }

  return(int16_Return);
}


//----------------------------------------------------------
// AQM1602 コマンド書き込み
//----------------------------------------------------------
// 引数：
// uint8_t *puint8_JobNum : 処理番号が格納される変数のポインタ

// uint8_t uint8_Number_TX : 送信データ数
// uint8_t *puint8_aData_TX : 送信データを格納するバッファのポインタ

// uint32_t uint32_Interval : 待ち時間 (mSec)

// struct sParam_Handle_I2Cx  *pstructParam_Handle_I2Cx
//              Handle I2C用パラメータの構造体のポインタ


// 戻り値：
//   -1 : 処理中
//    0 : OK終了
//    1 : NG終了
//----------------------------------------------------------
int16_t Write_Command_AQM1602(uint8_t *puint8_JobNum,
                              uint8_t uint8_Number_TX,
                              uint8_t *puint8_aData_TX,
                              uint32_t uint32_Interval,
            struct sParam_Handle_I2Cx  *pstructParam_Handle_I2Cx)
{
  //----------------------------------------------------
  // 呼び出す関数の引数に使用する処理番号は、
  // 必ず static の変数宣言をしてください。
  //----------------------------------------------------
  static uint8_t STC_uint8_JobNum_Time;  // Time_Interval処理番号

  //--------------------------------------------------------
  // Time_Interval用パラメータの構造体の宣言は、
  // 使用する関数内で、必ず static で宣言してください。
  //--------------------------------------------------------
  // Time_Interval用パラメータの構造体の宣言
  //--------------------------------------------------------
  static struct sParam_Time_Interval STC_structParam_Time_Interval;


  static uint8_t STC_uint8_JobNum_I2C;  // I2C処理番号

  static uint8_t STC_uint8_Count_TX;   // 送信回数カウンタ


  int16_t int16_Return;


  switch(*puint8_JobNum)
  {
  case 0:
    STC_uint8_JobNum_I2C = 0;  // I2C処理番号初期化
    STC_uint8_Count_TX = 0;    // 送信回数カウンタ初期化


    // I2C送信データセット
    pstructParam_Handle_I2Cx->puint8_aI2C_TxBuffer[0] = 0x00;
                                            // control bytee
    pstructParam_Handle_I2Cx->puint8_aI2C_TxBuffer[1]
                        = puint8_aData_TX[STC_uint8_Count_TX];
                                // data byte : Instruction

    pstructParam_Handle_I2Cx->uint16_vI2C_TxNumber
                                = (volatile uint16_t)2;


    (*puint8_JobNum)++;  // 次の処理番号に移行する。 : case 1:
    int16_Return = -1;   // 処理継続
    break;

  case 1:
    //----------------------------------------------------------
    // I2Cx Master送信 :
    //          Register指定 1byte + 設定データ 1byteを送信
    //----------------------------------------------------------
    //引数　：
    // uint8_t *puint8_JobNum : 処理番号

    // I2C_HandleTypeDef *pHandle_I2Cx : I2C handler declaration

    // struct sParam_Handle_I2Cx  *pstructParam_Handle_I2Cx
    //              Handle I2C用パラメータの構造体のポインタ


    //戻り値　：
    //   -1 : 処理中
    //    0 : OK
    //    1 : NG
    //----------------------------------------------------------
    int16_Return = I2Cx_Master_TxByte(&STC_uint8_JobNum_I2C,
                                      &Handle_I2C1,
                                      pstructParam_Handle_I2Cx);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }

    if(int16_Return != 0){
      // NG終了
      *puint8_JobNum = 0;  // 処理番号初期化
      // int16_Return : 結果
      break;
    }


    STC_uint8_JobNum_Time = 0;  // Time_Interval処理番号初期化
    STC_structParam_Time_Interval.uint32_Interval = uint32_Interval;
                                            // 待ち時間セット


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 2:
    //----------------------------------------------------------
    // 時間待ち : 単位 mSec
    //----------------------------------------------------------
    // 戻り値が -1 以外になるまで、繰り返し呼び出してください。
    //----------------------------------------------------------
    // 引数:
    // uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

    // struct sParam_Time_Interval *pstructParam_Time_Interval :
    //              Time_Interval用パラメータの構造体のポインタ


    // 戻り値:
    //   -1 : 処理中 : 時間が経過していない。
    //    0 : OK終了 : 時間が経過した。
    //    1 : NG終了
    //----------------------------------------------------------
    int16_Return = Time_Interval(&STC_uint8_JobNum_Time,
                                 &STC_structParam_Time_Interval);
    if(int16_Return == -1){
      // 処理中 : 時間未経過
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    STC_uint8_Count_TX++;  // 送信回数カウンタ インクリメント

    // 送信回数判定
    if(STC_uint8_Count_TX < uint8_Number_TX){
      // 指定された送信回数に達していない。

      // I2C送信データセット
      pstructParam_Handle_I2Cx->puint8_aI2C_TxBuffer[1]
                        = puint8_aData_TX[STC_uint8_Count_TX];
                                    // data byte : Instructio

      *puint8_JobNum = 1;  // 処理番号 1 に戻る。: case 1:
                           // case 1: ～ case 2: をループする。
      int16_Return = -1;   // 処理継続
      break;
    }


    *puint8_JobNum = 0;  // 処理番号初期化
    // int16_Return : 結果
    break;  // 処理終了

  default:
    *puint8_JobNum = 0;  // 処理番号初期化
    int16_Return = 1;    // NG
    break;  // NG
  }

  return(int16_Return);
}



//----------------------------------------------------------
// AQM1602 データ書き込み
//----------------------------------------------------------
// 引数：
// uint8_t *puint8_JobNum : 処理番号が格納される変数のポインタ

// uint8_t uint8_Address : データ書き込みアドレス

// uint8_t uint8_Number_TX : 送信データ数
// uint8_t *puint8_aData_TX : 送信データを格納するバッファのポインタ

// struct sParam_Handle_I2Cx  *pstructParam_Handle_I2Cx
//              Handle I2C用パラメータの構造体のポインタ


// 戻り値：
//   -1 : 処理中
//    0 : OK終了
//    1 : NG終了
//----------------------------------------------------------
int16_t Write_Data_AQM1602(uint8_t *puint8_JobNum,
                           uint8_t uint8_Address,
                           uint8_t uint8_Number_TX,
                           uint8_t *puint8_aData_TX,
            struct sParam_Handle_I2Cx  *pstructParam_Handle_I2Cx)
{
  static uint8_t STC_uint8_JobNum_I2C;  // I2C処理番号

  static uint8_t STC_uint8_Count_TX;  // 送信回数カウンタ
  static uint8_t STC_uint8_aData_TX[4];  // 送信データを格納する配列


  int16_t int16_Return;


  switch(*puint8_JobNum)
  {
  case 0:
    STC_uint8_JobNum_I2C = 0;  // I2C処理番号初期化
    STC_uint8_Count_TX = 0;    // 送信回数カウンタ初期化

    // 送信データセット
    STC_uint8_aData_TX[0] = uint8_Address;  // 表示アドレス


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 1:
    //-------------------------------------
    // 表示アドレスセット
    //-------------------------------------
    //----------------------------------------------------------
    // AQM1602 コマンド書き込み
    //----------------------------------------------------------
    // 引数：
    // uint8_t *puint8_JobNum : 処理番号が格納される変数のポインタ

    // uint8_t uint8_Number_TX : 送信データ数
    // uint8_t *puint8_aData_TX : 送信データを格納するバッファのポインタ

    // uint32_t uint32_Interval : 待ち時間 (mSec)

    // struct sParam_Handle_I2Cx  *pstructParam_Handle_I2Cx
    //              Handle I2C用パラメータの構造体のポインタ


    // 戻り値：
    //   -1 : 処理中
    //    0 : OK終了
    //    1 : NG終了
    //----------------------------------------------------------
    int16_Return = Write_Command_AQM1602(&STC_uint8_JobNum_I2C,
                                         (uint8_t)1,
                                         STC_uint8_aData_TX,
                                         (uint32_t)2,
                                         pstructParam_Handle_I2Cx);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }

    if(int16_Return != 0){
      // NG終了
      *puint8_JobNum = 0;  // 処理番号初期化
      // int16_Return : 結果
      break;  // 処理終了
    }


    // 送信データセット
    pstructParam_Handle_I2Cx->puint8_aI2C_TxBuffer[0] = 0x40;
                                            // control byte
    pstructParam_Handle_I2Cx->puint8_aI2C_TxBuffer[1]
                        = puint8_aData_TX[STC_uint8_Count_TX];
                                    // data byte ; 表示データ

    pstructParam_Handle_I2Cx->uint16_vI2C_TxNumber
                                    = (volatile uint16_t)2;


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 2:
    //------------------------------------
    // 表示データ書き込み
    //------------------------------------
    //----------------------------------------------------------
    // I2Cx Master送信
    //----------------------------------------------------------
    //引数　：
    // uint8_t *puint8_JobNum : 処理番号

    // I2C_HandleTypeDef *pHandle_I2Cx : I2C handler declaration

    // struct sParam_Handle_I2Cx  *pstructParam_Handle_I2Cx
    //              Handle I2C用パラメータの構造体のポインタ


    //戻り値　：
    //   -1 : 処理中
    //    0 : OK
    //    1 : NG
    //----------------------------------------------------------
    int16_Return = I2Cx_Master_TxByte(&STC_uint8_JobNum_I2C,
                                      &Handle_I2C1,
                                      pstructParam_Handle_I2Cx);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }

    if(int16_Return != 0){
      // NG終了
      *puint8_JobNum = 0;  // 処理番号初期化
      // int16_Return : 結果
      break;  // 処理終了
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。 : case 3:
    int16_Return = -1;   // 処理継続
    break;

  case 3:
    //---------------------------------------------------
    // LCD AQM1602 のビジーチェック
    //---------------------------------------------------
    // 引数：
    // uint8_t *puint8_JobNum : 処理番号が格納される変数のポインタ

    // 戻り値：
    //   -1 : 処理中
    //    0 : OK
    //    1 : NG
    //---------------------------------------------------
    int16_Return = Check_Busy_AQM1602(&STC_uint8_JobNum_I2C);
    if(int16_Return == -1){
      // 処理中
      break;  // 処理番号維持 : 処理継続 : case 3: をループ
    }

    if(int16_Return != 0){
      // NG終了
      *puint8_JobNum = 0;  // 処理番号初期化
      // int16_Return : 結果
      break;  // 処理終了
    }


    STC_uint8_Count_TX++;  // 送信回数カウンタ インクリメント

    // 送信回数判定
    if(STC_uint8_Count_TX < uint8_Number_TX){
      // 指定された送信回数に達していない。

      // 送信データセット
      pstructParam_Handle_I2Cx->puint8_aI2C_TxBuffer[1]
                        = puint8_aData_TX[STC_uint8_Count_TX];
                                    // data byte ; 表示データ

      *puint8_JobNum = 2;  // 処理番号 2 に移行する。: case 2:
      int16_Return = -1;   // 処理継続
      break;
    }


    *puint8_JobNum = 0;  // 処理番号初期化
    // int16_Return : 結果
    break;  // 処理終了

  default:
    *puint8_JobNum = 0;
    int16_Return = 1;
    break;  // NG
  }

  return(int16_Return);
}


//-----------------------------------------------------------------------------
// I2Cの読み込みができないため、ビジーフラグBFが判定できないので時間待ちする。
//-----------------------------------------------------------------------------
//---------------------------------------------------
// LCD AQM1602 のビジーチェック
//---------------------------------------------------
// 引数：
// uint8_t *puint8_JobNum : 処理番号が格納される変数のポインタ


// 戻り値：
//   -1 : 処理中
//    0 : OK
//    1 : NG
//---------------------------------------------------
int16_t Check_Busy_AQM1602(uint8_t *puint8_JobNum)
{
  //----------------------------------------------------
  // 呼び出す関数の引数に使用する処理番号は、
  // 必ず static の変数宣言をしてください。
  //----------------------------------------------------
  static uint8_t STC_uint8_JobNum_Time;  // Time_Interval処理番号

  //--------------------------------------------------------
  // Time_Interval用パラメータの構造体の宣言は、
  // 使用する関数内で、必ず static で宣言してください。
  //--------------------------------------------------------
  // Time_Interval用パラメータの構造体の宣言
  //--------------------------------------------------------
  static struct sParam_Time_Interval STC_structParam_Time_Interval;


  int16_t int16_Return;


  switch(*puint8_JobNum)
  {
  case 0:
    STC_uint8_JobNum_Time = 0;  // Time_Interval処理番号初期化
    STC_structParam_Time_Interval.uint32_Interval = (uint32_t)2;
                                    // 待ち時間セット : 2mSec


    (*puint8_JobNum)++;  // 次の処理番号に移行する。 : case 1:
    int16_Return = -1;   // 処理継続
    break;

  case 1:
    //----------------------------------------------------------
    // 時間待ち : 単位 mSec
    //----------------------------------------------------------
    // 戻り値が -1 以外になるまで、繰り返し呼び出してください。
    //----------------------------------------------------------
    // 引数:
    // uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

    // struct sParam_Time_Interval *pstructParam_Time_Interval :
    //              Time_Interval用パラメータの構造体のポインタ


    // 戻り値:
    //   -1 : 処理中 : 時間が経過していない。
    //    0 : OK終了 : 時間が経過した。
    //    1 : NG終了
    //----------------------------------------------------------
    int16_Return = Time_Interval(&STC_uint8_JobNum_Time,
                                 &STC_structParam_Time_Interval);
    if(int16_Return == -1){
      // 処理中 : 時間未経過
      break;  // 処理番号維持 : 処理継続 : case 1: をループ
    }


    *puint8_JobNum = 0;  // 処理番号初期化
    // int16_Return : 結果
    break;  // 処理終了

  default:
    *puint8_JobNum = 0;
    int16_Return = 1;
    break;  // NG
  }

  return(int16_Return);
}
