﻿/*
 * H_STM32F4_I2C_1.c
 *
 *  Created on: 2024/11/21
 *      Author: egaono-electronics
 */

#include "H_STM32F4_I2C_1.h"



//----------------------------------------------------------
// I2C handler declaration : I2C1
//----------------------------------------------------------
I2C_HandleTypeDef Handle_I2C1;


//------------------------------------------------------
// Handle I2C用パラメータの構造体の宣言 : I2C1
//------------------------------------------------------
struct sParam_Handle_I2Cx  GLB_structParam_Handle_I2C1;


// 送信Buffer : I2C1
uint8_t GLB_uint8_aI2C1_TxBuffer[def_I2C1_TxBufferSize];

// 受信Buffer : I2C1
uint8_t GLB_uint8_aI2C1_RxBuffer[def_I2C1_RxBufferSize];



//----------------------------------------------------------
// I2C MSP Initialization
//----------------------------------------------------------
// This function configures
//          the hardware resources used in this example:
//  - Peripheral's clock enable
//  - Peripheral's GPIO Configuration
//  - DMA configuration
//              for transmission request by peripheral
//  - NVIC configuration for DMA interrupt request enable
//----------------------------------------------------------
// 引数;
// I2C_HandleTypeDef *hi2c: I2C handle pointer


// 戻り値:
//    なし
//----------------------------------------------------------
void HAL_I2C_MspInit(I2C_HandleTypeDef *hi2c)
{
  GPIO_InitTypeDef GPIO_InitStruct;


  if(hi2c->Instance == I2C1)
  {
    //----------------------------------------------------------
    // I2C GPIO pin configuration
    //----------------------------------------------------------

    // Enable GPIO Clocks
    __HAL_RCC_GPIOB_CLK_ENABLE();


    //------------------------------------------------------
    // SCL と SDA のピンを I2C に設定する。
    //------------------------------------------------------

    //--------------------------------------------------
    // I2C TX GPIO pin configuration
    //--------------------------------------------------
    GPIO_InitStruct.Pin       = def_GPIO_PIN_I2C1_SCL;

    GPIO_InitStruct.Mode      = GPIO_MODE_AF_OD;

#ifdef def_I2C1_PULLUP
    GPIO_InitStruct.Pull      = GPIO_PULLUP;
#else  // def_I2C1_PULLUP
    GPIO_InitStruct.Pull      = GPIO_NOPULL;
#endif  // def_I2C1_PULLUP

    GPIO_InitStruct.Speed     = GPIO_SPEED_FAST;
    GPIO_InitStruct.Alternate = GPIO_AF4_I2C1;

    HAL_GPIO_Init(def_GPIOx_I2C1_SCL, &GPIO_InitStruct);
    //--------------------------------------------------


    //--------------------------------------------------
    // I2C RX GPIO pin configuration
    //--------------------------------------------------
    GPIO_InitStruct.Pin = def_GPIO_PIN_I2C1_SDA;

    HAL_GPIO_Init(def_GPIOx_I2C1_SDA, &GPIO_InitStruct);
    //--------------------------------------------------
    //------------------------------------------------------
    //----------------------------------------------------------


    // Enable peripheral Clock
    __HAL_RCC_I2C1_CLK_ENABLE();


    //----------------------------------------------
    // 割り込み設定
    //----------------------------------------------
    HAL_NVIC_SetPriority(I2C1_ER_IRQn, 12, 1);
    HAL_NVIC_EnableIRQ(I2C1_ER_IRQn);
    HAL_NVIC_SetPriority(I2C1_EV_IRQn, 12, 2);
    HAL_NVIC_EnableIRQ(I2C1_EV_IRQn);
    //----------------------------------------------


    GLB_structParam_Handle_I2C1.int16_vI2C_Initialize_Done = 1;
                                    // 初期化済みフラグON
  }
}



//----------------------------------------------------------
// I2C MSP De-Initialization
//----------------------------------------------------------
// This function frees the hardware resources
//                                  used in this example:
//  - Disable the Peripheral's clock
//  - Revert GPIO, DMA and NVIC configuration
//                                  to their default state
//----------------------------------------------------------
// 引数;
//  I2C_HandleTypeDef *hi2c: I2C handle pointer
//----------------------------------------------------------
void HAL_I2C_MspDeInit(I2C_HandleTypeDef *hi2c)
{
  if(hi2c->Instance == I2C1)
  {
    // Reset peripherals
    __HAL_RCC_I2C1_FORCE_RESET();
    __HAL_RCC_I2C1_RELEASE_RESET();


    // Disable peripherals and GPIO Clocks

    // Configure I2C Tx as alternate function
    HAL_GPIO_DeInit(def_GPIOx_I2C1_SCL, def_GPIO_PIN_I2C1_SCL);

    // Configure I2C Rx as alternate function
    HAL_GPIO_DeInit(def_GPIOx_I2C1_SDA, def_GPIO_PIN_I2C1_SDA);


    HAL_NVIC_DisableIRQ(I2C1_ER_IRQn);
    HAL_NVIC_DisableIRQ(I2C1_EV_IRQn);
  }
}
